==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCalendarResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCalendarResourceStringsDescription } from "./WebCalendarResourceStringsDescription";
/**
 * @hidden
 */
var WebCalendarResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCalendarResourceStringsDescriptionMetadata, _super);
    function WebCalendarResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCalendarResourceStringsDescriptionMetadata.b = function (a) {
        if (WebCalendarResourceStringsDescriptionMetadata.a == null) {
            WebCalendarResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCalendarResourceStringsDescriptionMetadata.c(WebCalendarResourceStringsDescriptionMetadata.a);
        }
        if (a.j(WebCalendarResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCalendarResourceStringsDescriptionMetadata.a);
    };
    WebCalendarResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CalendarResourceStrings");
        a.item("SelectMonth", "String");
        a.item("SelectYear", "String");
        a.item("SelectDate", "String");
        a.item("SelectRange", "String");
        a.item("SelectedDate", "String");
        a.item("StartDate", "String");
        a.item("EndDate", "String");
        a.item("PreviousMonth", "String");
        a.item("NextMonth", "String");
        a.item("PreviousYear", "String");
        a.item("NextYear", "String");
        a.item("PreviousYears", "String");
        a.item("NextYears", "String");
        a.item("WeekLabel", "String");
    };
    WebCalendarResourceStringsDescriptionMetadata.d = function (a) {
        WebCalendarResourceStringsDescriptionMetadata.b(a);
        a.aa("WebCalendarResourceStrings", function () { return new WebCalendarResourceStringsDescription(); });
        a.z("WebCalendarResourceStrings", WebCalendarResourceStringsDescriptionMetadata.a);
    };
    WebCalendarResourceStringsDescriptionMetadata.$t = markType(WebCalendarResourceStringsDescriptionMetadata, 'WebCalendarResourceStringsDescriptionMetadata');
    WebCalendarResourceStringsDescriptionMetadata.a = null;
    return WebCalendarResourceStringsDescriptionMetadata;
}(Base));
export { WebCalendarResourceStringsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCalendarResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCalendarResourceStringsDescription } from "./WebCalendarResourceStringsDescription";
/**
 * @hidden
 */
var WebCalendarResourceStringsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCalendarResourceStringsDescriptionMetadata, _super);
    function WebCalendarResourceStringsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCalendarResourceStringsDescriptionMetadata.b = function (a) {
        if (WebCalendarResourceStringsDescriptionMetadata.a == null) {
            WebCalendarResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCalendarResourceStringsDescriptionMetadata.c(WebCalendarResourceStringsDescriptionMetadata.a);
        }
        if (a.k(WebCalendarResourceStringsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCalendarResourceStringsDescriptionMetadata.a);
    };
    WebCalendarResourceStringsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CalendarResourceStrings");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("SelectMonth", "String");
        a.item("SelectYear", "String");
        a.item("SelectDate", "String");
        a.item("SelectRange", "String");
        a.item("SelectedDate", "String");
        a.item("StartDate", "String");
        a.item("EndDate", "String");
        a.item("PreviousMonth", "String");
        a.item("NextMonth", "String");
        a.item("PreviousYear", "String");
        a.item("NextYear", "String");
        a.item("PreviousYears", "String");
        a.item("NextYears", "String");
        a.item("WeekLabel", "String");
    };
    WebCalendarResourceStringsDescriptionMetadata.d = function (a) {
        WebCalendarResourceStringsDescriptionMetadata.b(a);
        a.ac("WebCalendarResourceStrings", function () { return new WebCalendarResourceStringsDescription(); });
        a.ab("WebCalendarResourceStrings", WebCalendarResourceStringsDescriptionMetadata.a);
    };
    WebCalendarResourceStringsDescriptionMetadata.$t = markType(WebCalendarResourceStringsDescriptionMetadata, 'WebCalendarResourceStringsDescriptionMetadata');
    WebCalendarResourceStringsDescriptionMetadata.a = null;
    return WebCalendarResourceStringsDescriptionMetadata;
}(Base));
export { WebCalendarResourceStringsDescriptionMetadata };
